import { env } from '$env/dynamic/public';

export const apiCall = async (method, endpoint, token, body, contentType) => {
    const headers = (() => {
        if (!!token) {
            return { 'token': token };
        }

        return {}
    })();

    return (await
        fetch(
            `${env.PUBLIC_API_URL}/${endpoint}`,
            { method: method, headers: { 'Content-Type': contentType, ...headers }, body: body })

    );
};

export const authenticate = async (code) => {
    return await apiCall('GET', `auth?code=${code}`, null);
};

export const getMe = async (token) => {
    return await apiCall('GET', 'me', token);
};

export const getGuildIntros = async (guild, token) => {
    return await apiCall('GET', `intros/${guild}`, token);
};

export const addGuildIntro = async (guild, url, title, token) => {
    return await apiCall('GET', `intros/${guild}/add?url=${encodeURIComponent(url)}&name=${encodeURIComponent(title)}`, token);
};

export const chooseIntro = async (guild, channel, selectedIntros, token) => {
    for (const intro of selectedIntros) {
        await apiCall('POST', `intros/${guild}/${channel}/${intro}`, token);
    }
};

export const removeIntro = async (guild, channel, selectedIntros, token) => {
    for (const intro of selectedIntros) {
        await apiCall('POST', `intros/${guild}/${channel}/${intro}/remove`, token);
    }
};

export const uploadIntro = async (guild, name, file, token) => {
    await apiCall('POST', `intros/${guild}/upload?name=${encodeURIComponent(name)}`, token, file);
}

export const deleteIntro = async (guild, selectedIntros, token) => {
    await apiCall('DELETE', `intros/${guild}/delete`, token, JSON.stringify(selectedIntros), 'application/json');
}
