import { env } from '$env/dynamic/public';
import { readable, writable } from 'svelte/store';
import { getMe, getGuildIntros, addGuildIntro } from './api.js';

function createMemberStore() {
    const { subscribe, set, update } = writable(null)

    return {
        subscribe: subscribe,
        set: set,
        addIntro: (intro: IntroIndex) => { update((n) => n.intros.push(intro)); return intro },
        pullData: async (token) => {
            const response = await getMe(token);

            if (!response.ok) {
                throw new Error(await response.text());
            } else {
                const body = await response.json();
                set({ token: token, ...body.Me }) 
            }
        }
    }
}

function createIntroStore() {
    const { subscribe, set, update } = writable(new Map())

    return {
        subscribe: subscribe,
        addIntro: async (guild, url, title, token) => {
            const response = await addGuildIntro(guild, url, title, token);

            if (!response.ok) {
                throw new Error(await response.body);
            }
        },
        fetchIntros: async (guilds) => {
            let intros = new Map();

            for (const guild of guilds) {
                const response = await getGuildIntros(guild.id, null);
                const body = await response.json();

                if (response !== "NoGuildFound") {
                    let guild_intros = new Map();

                    Object.entries(body.Intros).forEach(([index, intro]) => {
                        if (!!intro.File) {
                            guild_intros.set(index, { name: intro.File.friendlyName, filename: intro.File.filename });
                        } else if (!!intro.Online) {
                            guild_intros.set(index, { name: intro.Online.friendlyName, filename: intro.Online.filename });
                        }
                    })

                    intros.set(guild.id, guild_intros);
                }
            }

            set(intros)
        }
    }
}

export const intros = createIntroStore()
export const member = createMemberStore()

